@@ -9,6 +9,7 @@ import (
 	corev1 "k8s.io/api/core/v1"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
 func TestDesiredDNSDaemonset(t *testing.T) {
@@ -16,6 +17,7 @@ func TestDesiredDNSDaemonset(t *testing.T) {
 	clusterIP := "172.30.77.10"
 	coreDNSImage := "quay.io/openshift/coredns:test"
 	openshiftCLIImage := "openshift/origin-cli:test"
+	kubeRBACProxyImage := "quay.io/openshift/origin-kube-rbac-proxy:test"
 
 	dns := &operatorv1.DNS{
 		ObjectMeta: metav1.ObjectMeta{
@@ -23,12 +25,12 @@ func TestDesiredDNSDaemonset(t *testing.T) {
 		},
 	}
 
-	if ds, err := desiredDNSDaemonSet(dns, clusterIP, clusterDomain, coreDNSImage, openshiftCLIImage); err != nil {
+	if ds, err := desiredDNSDaemonSet(dns, clusterIP, clusterDomain, coreDNSImage, openshiftCLIImage, kubeRBACProxyImage); err != nil {
 		t.Errorf("invalid dns daemonset: %v", err)
 	} else {
 		// Validate the daemonset
-		if len(ds.Spec.Template.Spec.Containers) != 2 {
-			t.Errorf("expected number of daemonset containers 2, got %d", len(ds.Spec.Template.Spec.Containers))
+		if len(ds.Spec.Template.Spec.Containers) != 3 {
+			t.Errorf("expected number of daemonset containers 3, got %d", len(ds.Spec.Template.Spec.Containers))
 		}
 		for _, c := range ds.Spec.Template.Spec.Containers {
 			switch c.Name {
@@ -57,6 +59,10 @@ func TestDesiredDNSDaemonset(t *testing.T) {
 				} else if clusterDomain != domain {
 					t.Errorf("expected CLUSTER_DOMAIN env for dns node resolver image %q, got %q", clusterDomain, domain)
 				}
+			case "kube-rbac-proxy":
+				if e, a := kubeRBACProxyImage, c.Image; e != a {
+					t.Errorf("expected daemonset kube rbac proxy image %q, got %q", e, a)
+				}
 			default:
 				t.Errorf("unexpected daemonset container %q", c.Name)
 			}
@@ -104,6 +110,17 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 			},
 			expect: true,
 		},
+		{
+			description: "if .spec.template.spec.volumes changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				daemonset.Spec.Template.Spec.Volumes = []corev1.Volume{
+					{
+						Name: "test",
+					},
+				}
+			},
+			expect: true,
+		},
 		{
 			description: "if the dns-node-resolver container image is changed",
 			mutate: func(daemonset *appsv1.DaemonSet) {
@@ -118,6 +135,13 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 			},
 			expect: true,
 		},
+		{
+			description: "if the kube rbac proxy image is changed",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				daemonset.Spec.Template.Spec.Containers[2].Image = "openshift/origin-kube-rbac-proxy:latest"
+			},
+			expect: true,
+		},
 		{
 			description: "if a container command length changed",
 			mutate: func(daemonset *appsv1.DaemonSet) {
@@ -132,6 +156,20 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 			},
 			expect: true,
 		},
+		{
+			description: "if the readiness probe endpoint changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				daemonset.Spec.Template.Spec.Containers[0].ReadinessProbe.Handler.HTTPGet.Path = "/ready"
+			},
+			expect: true,
+		},
+		{
+			description: "if the readiness probe period changes",
+			mutate: func(daemonset *appsv1.DaemonSet) {
+				daemonset.Spec.Template.Spec.Containers[0].ReadinessProbe.PeriodSeconds = 2
+			},
+			expect: true,
+		},
 	}
 
 	for _, tc := range testCases {
@@ -152,6 +190,18 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 									"a",
 									"b",
 								},
+								ReadinessProbe: &corev1.Probe{
+									PeriodSeconds: 10,
+									Handler: corev1.Handler{
+										HTTPGet: &corev1.HTTPGetAction{
+											Path: "/health",
+											Port: intstr.IntOrString{
+												IntVal: int32(8080),
+											},
+											Scheme: "HTTP",
+										},
+									},
+								},
 							},
 							{
 								Name:  "dns-node-resolver",
@@ -161,6 +211,14 @@ func TestDaemonsetConfigChanged(t *testing.T) {
 									"d",
 								},
 							},
+							{
+								Name:  "kube-rbac-proxy",
+								Image: "openshift/origin-kube-rbac-proxy:v4.0",
+								Command: []string{
+									"e",
+									"f",
+								},
+							},
 						},
 						NodeSelector: map[string]string{
 							"beta.kubernetes.io/os": "linux",
